==> google-cloud-aiplatform-1.11.0-py310h5588dad_0.tar.bz2: Lib/site-packages/google/cloud/aiplatform_v1/services/index_endpoint_service/transports/base.py <==
# -*- coding: utf-8 -*-
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import abc
from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
import pkg_resources

import google.auth  # type: ignore
import google.api_core
from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1
from google.api_core import retry as retries
from google.api_core import operations_v1
from google.auth import credentials as ga_credentials  # type: ignore
from google.oauth2 import service_account  # type: ignore

from google.cloud.aiplatform_v1.types import index_endpoint
from google.cloud.aiplatform_v1.types import index_endpoint as gca_index_endpoint
from google.cloud.aiplatform_v1.types import index_endpoint_service
from google.longrunning import operations_pb2  # type: ignore

try:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
        gapic_version=pkg_resources.get_distribution(
            "google-cloud-aiplatform",
        ).version,
    )
except pkg_resources.DistributionNotFound:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()


class IndexEndpointServiceTransport(abc.ABC):
    """Abstract transport class for IndexEndpointService."""

    AUTH_SCOPES = ("https://www.googleapis.com/auth/cloud-platform",)

    DEFAULT_HOST: str = "aiplatform.googleapis.com"

    def __init__(
        self,
        *,
        host: str = DEFAULT_HOST,
        credentials: ga_credentials.Credentials = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        **kwargs,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to.
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scopes (Optional[Sequence[str]]): A list of scopes.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.
        """
        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
        if ":" not in host:
            host += ":443"
        self._host = host

        scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}

        # Save the scopes.
        self._scopes = scopes

        # If no credentials are provided, then determine the appropriate
        # defaults.
        if credentials and credentials_file:
            raise core_exceptions.DuplicateCredentialArgs(
                "'credentials_file' and 'credentials' are mutually exclusive"
            )

        if credentials_file is not None:
            credentials, _ = google.auth.load_credentials_from_file(
                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
            )
        elif credentials is None:
            credentials, _ = google.auth.default(
                **scopes_kwargs, quota_project_id=quota_project_id
            )

        # If the credentials are service account credentials, then always try to use self signed JWT.
        if (
            always_use_jwt_access
            and isinstance(credentials, service_account.Credentials)
            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
        ):
            credentials = credentials.with_always_use_jwt_access(True)

        # Save the credentials.
        self._credentials = credentials

    def _prep_wrapped_messages(self, client_info):
        # Precompute the wrapped methods.
        self._wrapped_methods = {
            self.create_index_endpoint: gapic_v1.method.wrap_method(
                self.create_index_endpoint,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_index_endpoint: gapic_v1.method.wrap_method(
                self.get_index_endpoint, default_timeout=None, client_info=client_info,
            ),
            self.list_index_endpoints: gapic_v1.method.wrap_method(
                self.list_index_endpoints,
                default_timeout=None,
                client_info=client_info,
            ),
            self.update_index_endpoint: gapic_v1.method.wrap_method(
                self.update_index_endpoint,
                default_timeout=None,
                client_info=client_info,
            ),
            self.delete_index_endpoint: gapic_v1.method.wrap_method(
                self.delete_index_endpoint,
                default_timeout=None,
                client_info=client_info,
            ),
            self.deploy_index: gapic_v1.method.wrap_method(
                self.deploy_index, default_timeout=None, client_info=client_info,
            ),
            self.undeploy_index: gapic_v1.method.wrap_method(
                self.undeploy_index, default_timeout=None, client_info=client_info,
            ),
            self.mutate_deployed_index: gapic_v1.method.wrap_method(
                self.mutate_deployed_index,
                default_timeout=None,
                client_info=client_info,
            ),
        }

    def close(self):
        """Closes resources associated with the transport.

       .. warning::
            Only call this method if the transport is NOT shared
            with other clients - this may cause errors in other clients!
        """
        raise NotImplementedError()

    @property
    def operations_client(self):
        """Return the client designed to process long-running operations."""
        raise NotImplementedError()

    @property
    def create_index_endpoint(
        self,
    ) -> Callable[
        [index_endpoint_service.CreateIndexEndpointRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def get_index_endpoint(
        self,
    ) -> Callable[
        [index_endpoint_service.GetIndexEndpointRequest],
        Union[index_endpoint.IndexEndpoint, Awaitable[index_endpoint.IndexEndpoint]],
    ]:
        raise NotImplementedError()

    @property
    def list_index_endpoints(
        self,
    ) -> Callable[
        [index_endpoint_service.ListIndexEndpointsRequest],
        Union[
            index_endpoint_service.ListIndexEndpointsResponse,
            Awaitable[index_endpoint_service.ListIndexEndpointsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def update_index_endpoint(
        self,
    ) -> Callable[
        [index_endpoint_service.UpdateIndexEndpointRequest],
        Union[
            gca_index_endpoint.IndexEndpoint,
            Awaitable[gca_index_endpoint.IndexEndpoint],
        ],
    ]:
        raise NotImplementedError()

    @property
    def delete_index_endpoint(
        self,
    ) -> Callable[
        [index_endpoint_service.DeleteIndexEndpointRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def deploy_index(
        self,
    ) -> Callable[
        [index_endpoint_service.DeployIndexRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def undeploy_index(
        self,
    ) -> Callable[
        [index_endpoint_service.UndeployIndexRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def mutate_deployed_index(
        self,
    ) -> Callable[
        [index_endpoint_service.MutateDeployedIndexRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()


__all__ = ("IndexEndpointServiceTransport",)

==> google-cloud-aiplatform-1.14.0-py310h5588dad_0.tar.bz2: Lib/site-packages/google/cloud/aiplatform_v1/services/index_endpoint_service/transports/base.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import abc
from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
import pkg_resources

import google.auth  # type: ignore
import google.api_core
from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1
from google.api_core import retry as retries
from google.api_core import operations_v1
from google.auth import credentials as ga_credentials  # type: ignore
from google.oauth2 import service_account  # type: ignore

from google.cloud.aiplatform_v1.types import index_endpoint
from google.cloud.aiplatform_v1.types import index_endpoint as gca_index_endpoint
from google.cloud.aiplatform_v1.types import index_endpoint_service
from google.longrunning import operations_pb2  # type: ignore

try:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
        gapic_version=pkg_resources.get_distribution(
            "google-cloud-aiplatform",
        ).version,
    )
except pkg_resources.DistributionNotFound:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()


class IndexEndpointServiceTransport(abc.ABC):
    """Abstract transport class for IndexEndpointService."""

    AUTH_SCOPES = ("https://www.googleapis.com/auth/cloud-platform",)

    DEFAULT_HOST: str = "aiplatform.googleapis.com"

    def __init__(
        self,
        *,
        host: str = DEFAULT_HOST,
        credentials: ga_credentials.Credentials = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        **kwargs,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to.
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scopes (Optional[Sequence[str]]): A list of scopes.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.
        """

        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
        if ":" not in host:
            host += ":443"
        self._host = host

        scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}

        # Save the scopes.
        self._scopes = scopes

        # If no credentials are provided, then determine the appropriate
        # defaults.
        if credentials and credentials_file:
            raise core_exceptions.DuplicateCredentialArgs(
                "'credentials_file' and 'credentials' are mutually exclusive"
            )

        if credentials_file is not None:
            credentials, _ = google.auth.load_credentials_from_file(
                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
            )
        elif credentials is None:
            credentials, _ = google.auth.default(
                **scopes_kwargs, quota_project_id=quota_project_id
            )

        # If the credentials are service account credentials, then always try to use self signed JWT.
        if (
            always_use_jwt_access
            and isinstance(credentials, service_account.Credentials)
            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
        ):
            credentials = credentials.with_always_use_jwt_access(True)

        # Save the credentials.
        self._credentials = credentials

    def _prep_wrapped_messages(self, client_info):
        # Precompute the wrapped methods.
        self._wrapped_methods = {
            self.create_index_endpoint: gapic_v1.method.wrap_method(
                self.create_index_endpoint,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_index_endpoint: gapic_v1.method.wrap_method(
                self.get_index_endpoint,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_index_endpoints: gapic_v1.method.wrap_method(
                self.list_index_endpoints,
                default_timeout=None,
                client_info=client_info,
            ),
            self.update_index_endpoint: gapic_v1.method.wrap_method(
                self.update_index_endpoint,
                default_timeout=None,
                client_info=client_info,
            ),
            self.delete_index_endpoint: gapic_v1.method.wrap_method(
                self.delete_index_endpoint,
                default_timeout=None,
                client_info=client_info,
            ),
            self.deploy_index: gapic_v1.method.wrap_method(
                self.deploy_index,
                default_timeout=None,
                client_info=client_info,
            ),
            self.undeploy_index: gapic_v1.method.wrap_method(
                self.undeploy_index,
                default_timeout=None,
                client_info=client_info,
            ),
            self.mutate_deployed_index: gapic_v1.method.wrap_method(
                self.mutate_deployed_index,
                default_timeout=None,
                client_info=client_info,
            ),
        }

    def close(self):
        """Closes resources associated with the transport.

        .. warning::
             Only call this method if the transport is NOT shared
             with other clients - this may cause errors in other clients!
        """
        raise NotImplementedError()

    @property
    def operations_client(self):
        """Return the client designed to process long-running operations."""
        raise NotImplementedError()

    @property
    def create_index_endpoint(
        self,
    ) -> Callable[
        [index_endpoint_service.CreateIndexEndpointRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def get_index_endpoint(
        self,
    ) -> Callable[
        [index_endpoint_service.GetIndexEndpointRequest],
        Union[index_endpoint.IndexEndpoint, Awaitable[index_endpoint.IndexEndpoint]],
    ]:
        raise NotImplementedError()

    @property
    def list_index_endpoints(
        self,
    ) -> Callable[
        [index_endpoint_service.ListIndexEndpointsRequest],
        Union[
            index_endpoint_service.ListIndexEndpointsResponse,
            Awaitable[index_endpoint_service.ListIndexEndpointsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def update_index_endpoint(
        self,
    ) -> Callable[
        [index_endpoint_service.UpdateIndexEndpointRequest],
        Union[
            gca_index_endpoint.IndexEndpoint,
            Awaitable[gca_index_endpoint.IndexEndpoint],
        ],
    ]:
        raise NotImplementedError()

    @property
    def delete_index_endpoint(
        self,
    ) -> Callable[
        [index_endpoint_service.DeleteIndexEndpointRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def deploy_index(
        self,
    ) -> Callable[
        [index_endpoint_service.DeployIndexRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def undeploy_index(
        self,
    ) -> Callable[
        [index_endpoint_service.UndeployIndexRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def mutate_deployed_index(
        self,
    ) -> Callable[
        [index_endpoint_service.MutateDeployedIndexRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def kind(self) -> str:
        raise NotImplementedError()


__all__ = ("IndexEndpointServiceTransport",)
